@@ -9,7 +9,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 
 sub error
@@ -498,6 +498,12 @@ Image::PNG - Read and write PNG files
     $png->read_file ("crazy.png");
     printf "Your PNG is %d x %d\n", $png->width, $png->height;
 
+=head1 VERSION
+
+This documents version 0.23 of Image::PNG corresponding
+to git commit L<dff4678b1deaa602af5b7a155989cead1afbe026|https://github.com/benkasminbullock/Image-PNG/commit/dff4678b1deaa602af5b7a155989cead1afbe026> made on Sun Dec 11 08:12:23 2016 +0900.
+
+
 =head1 DESCRIPTION
 
 Image::PNG is a layer on top of L<Image::PNG::Libpng>. Whereas
@@ -794,7 +800,7 @@ Ben Bullock, <bkb@cpan.org>
 =head1 COPYRIGHT & LICENCE
 
 The Image::PNG package and associated files are copyright (C)
-2015 Ben Bullock.
+2016 Ben Bullock.
 
 You can use, copy, modify and redistribute Image::PNG and
 associated files under the Perl Artistic Licence or the GNU General
