@@ -9,7 +9,7 @@ use Carp;
 use Image::PNG::Const ':all';
 use Image::PNG::Libpng ':all';
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 
 sub new
@@ -62,10 +62,12 @@ sub Image::PNG::Container::open
     }
     my $file;
     if ($object->{read_only}) {
-        open $file, "<:raw", $object->{file_name};
+        open $file, "<:raw", $object->{file_name}
+            or croak "open $object->{file_name} failed: $!";
     }
     else {
-        open $file, ">:raw", $object->{file_name};
+        open $file, ">:raw", $object->{file_name}
+            or croak "open $object->{file_name} failed: $!";
     }
     init_io ($object->{png}, $file);
     $object->{file} = $file;
@@ -77,6 +79,9 @@ sub read
     if (! $object->{read_only}) {
         croak "Read on a write file";
     }
+    if (! $object->{file}) {
+	croak "No file in Image::PNG::Container object";
+    }
     Image::PNG::Libpng::read_png ($object->{png});
     $object->{read_ok} = 1;
     if ($object->{file}) {
